function printTable93(data)

    if ~iscell(data)
        data = {data};
    end
    
    ratios  = zeros(size(data));
    tn      = zeros(size(data));
    to      = zeros(size(data));
    
    for j = 1:length(data)
        d   = data{j};
        
        new = d.getSepLam;
        old = d.seplambda;
       
        % Problem specs m=n=? and s=?
        fprintf('%4d & ',d.mn);
        fprintf('%4d & ',d.s);
        
        % Data for new method
        fprintf('%5d & ',new.n_f);
        fprintf('%3d & ',new.n_c);
        fprintf('%7d & ',new.n_pts);
        fprintf('%7d & ',new.n_fin);
        fprintf('%7.0f & ',new.t);
        tn(j) = new.t;

        % Data for old method of Gu and Overton (running time)
        fprintf('%7.0f & ',old.t);
        to(j) = old.t;
        
        ratios(j) = old.t/old.t_init;
        
        % Relative difference of computed estimates
        % positive means our method found the better (lower) estimate
        fprintf('$%s$ \\\\ \n',getLongE((old.sl - new.sl)/new.sl,2));

    end
    
    fprintf('\nSpeedups of new method: ');
    fprintf('%6.1f ',to./tn);
    fprintf('\n\n');
    
    fprintf('Gu & Overton: total_time/init_time: ');
    fprintf('%6.3f ',ratios);
    fprintf('\n');
    fprintf('Gu & Overton: init_time/total_time: ');
    fprintf('%6.3f ',1./ratios);
    fprintf('\n');

    % This following code is only to be used when called manually when data
    % contains all the data needed for Table 9.3.  Since the experiments
    % are run on multiples nodes on the cluster, I manually assemble the
    % data variable after the fact and then call this function with the
    % following lines uncommented.  
    % The code just averages the pairs of values in ratios that correspond
    % to the same dimension value(=m=n).  See Remark 9.1.
  
%     assert(numel(ratios) == 6,'need to manually assemble data for Table 9.3');
%     r1  = ratios(1:2:end);
%     r2  = ratios(2:2:end);
%     s   = mean([r1(:) r2(:)],2);
%     fprintf('Average idealized speeds per dimension m=n: ');
%     fprintf('%6.1f ',s);
%     fprintf('\n');
    
end