function data = runGuOverton(A,B,plots)
% This runs the method of Gu and Overton method, seplambda.m, for computing
% sep_\lambda(A,B)^D, which returns the following information
%
%   data:       struct containing the following data:
%   .sl         computed value of sep_lambda
%   .t          total wall-clock time to run seplambda
%   .t_init     wall-clock time for seplambda's initialization procedure to
%               compute an upper bound 
%
% and makes the following plot:
%   
%   a plot of the eigenvalues and final epsln-pseudospectra of A and B 
%
% Authored by: Tim Mitchell
% Email: mitchell@mpi-magdeburg.mpg.de
% Date: November 7, 2019
% License: AGPL
%
% =========================================================================
% |  runGuOverton.m                                                       |
% |  Copyright (C) 2019 Tim Mitchell                                      |
% |                                                                       |
% |  This program is free software: you can redistribute it and/or modify |
% |  it under the terms of the GNU Affero General Public License as       |
% |  published by the Free Software Foundation, either version 3 of       |
% |  the License, or (at your option) any later version.                  |
% |                                                                       |
% |  This program is distributed in the hope that it will be useful,      |
% |  but WITHOUT ANY WARRANTY; without even the implied warranty of       |
% |  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
% |  GNU Affero General Public License for more details.                  |
% |                                                                       |
% |  You should have received a copy of the GNU Affero General Public     |
% |  License along with this program.  If not, see                        |
% |  <http://www.gnu.org/licenses/agpl.html>.                             |
% =========================================================================

    t_start                 = tic();
    [upper,lower,~,t_init]  = seplambda(A,B,1e-14,2);
    t_total                 = toc(t_start);
    
    data.sl                 = mean([ upper lower ]);
    data.t                  = t_total;
    data.t_init             = t_init;
    
    if nargin < 3 || ~plots
        return
    end
    
    plotEigs(A,B);
    makePsPlots(A,B,sl);
    largerTicks();
   
end