function s = getLongE(x,digits)
%   getLongE:
%       Given a real value x, convert it to a %g formatted string s with
%       the desired number of significant digits, and then if there is an
%       exponent term in the %g formatting, further convert the string
%       representation into a LaTeX-formatted string in scientific
%       notation.
%
%   INPUT:
%       x                           [ real scalar ]
%
%       digits                      [ positive integer ]
%
%   OUTPUT:         
%       s                           [ character string ]
%
%
% Authored by: Tim Mitchell
% Email: mitchell@mpi-magdeburg.mpg.de
% Date: August 26, 2021
% License: AGPL
%
% =========================================================================
% |  getLongE.m                                                           |
% |  Copyright (C) 2021 Tim Mitchell                                      |
% |                                                                       |
% |  This program is free software: you can redistribute it and/or modify |
% |  it under the terms of the GNU Affero General Public License as       |
% |  published by the Free Software Foundation, either version 3 of       |
% |  the License, or (at your option) any later version.                  |
% |                                                                       |
% |  This program is distributed in the hope that it will be useful,      |
% |  but WITHOUT ANY WARRANTY; without even the implied warranty of       |
% |  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
% |  GNU Affero General Public License for more details.                  |
% |                                                                       |
% |  You should have received a copy of the GNU Affero General Public     |
% |  License along with this program.  If not, see                        |
% |  <http://www.gnu.org/licenses/agpl.html>.                             |
% =========================================================================

    if nargin < 2
        digits = 15;
    end
    s   = sprintf('%.*e',digits,x); 
    ss  = strsplit(s,'e');
    if length(ss) > 1
        s = sprintf('%s \\times 10^{%d}',ss{1},str2double(ss{2}));
    end
end
