function h = makePsPlots(A,B,eps1,eps2,res)
% This adds contour plots of the epsln-pseudospectral boundaries of both 
% A and B to the current figure, using its current xlim and ylim:
%   A: solid blue
%   B: dashed red
%
%
% Authored by: Tim Mitchell
% Email: mitchell@mpi-magdeburg.mpg.de
% Date: November 7, 2019
% License: AGPL
%
% =========================================================================
% |  makePsPlots.m                                                        |
% |  Copyright (C) 2019 Tim Mitchell                                      |
% |                                                                       |
% |  This program is free software: you can redistribute it and/or modify |
% |  it under the terms of the GNU Affero General Public License as       |
% |  published by the Free Software Foundation, either version 3 of       |
% |  the License, or (at your option) any later version.                  |
% |                                                                       |
% |  This program is distributed in the hope that it will be useful,      |
% |  but WITHOUT ANY WARRANTY; without even the implied warranty of       |
% |  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
% |  GNU Affero General Public License for more details.                  |
% |                                                                       |
% |  You should have received a copy of the GNU Affero General Public     |
% |  License along with this program.  If not, see                        |
% |  <http://www.gnu.org/licenses/agpl.html>.                             |
% =========================================================================

    if nargin < 4 || isempty(eps2)
        eps2 = eps1;
    end
    
    if nargin < 5
        res = 200;
    end
    
    x_range = xlim();
    y_range = ylim();
    
    x   = linspace(x_range(1),x_range(2),res);
    y   = linspace(y_range(1),y_range(2),res);
    
    [X,Y,Z] = sigmaMinGrid(A,x,y);  
    [~,h1]  = contour(X,Y,Z,[eps1 eps1],'b-','LineWidth',2); 
    % plotTransparent(X,Y,Z,eps1,[0 0 1],0.15);
    
    [X,Y,Z] = sigmaMinGrid(B,x,y);   
    [~,h2]  = contour(X,Y,Z,[eps2 eps2],'r:','LineWidth',2); 
    % plotTransparent(X,Y,Z,eps2,[1 0 0],0.15);
    
    h       = [h1 h2];

end