function redrawFn = plotContours(X,Y,Z,levels,fs,ls)
% Make a contour plot, but with a little more control of the labels.
%
%
% Authored by: Tim Mitchell
% Email: mitchell@mpi-magdeburg.mpg.de
% Date: July 14, 2019
% License: AGPL
%
% =========================================================================
% |  plotContours.m                                                       |
% |  Copyright (C) 2019 Tim Mitchell                                      |
% |                                                                       |
% |  This program is free software: you can redistribute it and/or modify |
% |  it under the terms of the GNU Affero General Public License as       |
% |  published by the Free Software Foundation, either version 3 of       |
% |  the License, or (at your option) any later version.                  |
% |                                                                       |
% |  This program is distributed in the hope that it will be useful,      |
% |  but WITHOUT ANY WARRANTY; without even the implied warranty of       |
% |  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
% |  GNU Affero General Public License for more details.                  |
% |                                                                       |
% |  You should have received a copy of the GNU Affero General Public     |
% |  License along with this program.  If not, see                        |
% |  <http://www.gnu.org/licenses/agpl.html>.                             |
% =========================================================================
    
    if nargin < 6
        ls = {};
    else
        ls = {'LineStyle',ls};
    end
    
    % Plot basic contours
    [C,h] = contour(X,Y,Z,levels,'LineWidth',2,'LabelSpacing',575,ls{:});  
    clabel(C,h,'FontSize',fs)
    
    redrawLabels();
       
    redrawFn = @redrawLabels;
    
    function redrawLabels()
        h.ShowText='on';
        drawnow();
        txt = get(h,'TextPrims');
        vs = str2double(get(txt,'String'));
        for k = 1:length(vs)
            if mod(vs(k),1) > 0
                set(txt(k),'String',sprintf('%0.4g',vs(k)))
            end
        end
    end

end