function fn = getCheckEpsilonValuesFn(A,B,eps_tol)
% This returns a functiom handle for asserting that the search point z0
% satisfies the assumptions with respect to eps1 and eps2.
% 
% Authored by: Tim Mitchell
% Email: mitchell@mpi-magdeburg.mpg.de
% Date: September 16, 2019
% License: AGPL
%
% =========================================================================
% |  getCheckEpsilonValuesFn.m                                            |
% |  Copyright (C) 2019 Tim Mitchell                                      |
% |                                                                       |
% |  This program is free software: you can redistribute it and/or modify |
% |  it under the terms of the GNU Affero General Public License as       |
% |  published by the Free Software Foundation, either version 3 of       |
% |  the License, or (at your option) any later version.                  |
% |                                                                       |
% |  This program is distributed in the hope that it will be useful,      |
% |  but WITHOUT ANY WARRANTY; without even the implied warranty of       |
% |  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
% |  GNU Affero General Public License for more details.                  |
% |                                                                       |
% |  You should have received a copy of the GNU Affero General Public     |
% |  License along with this program.  If not, see                        |
% |  <http://www.gnu.org/licenses/agpl.html>.                             |
% =========================================================================
    
    z0_cur  = [];
    e1_cur  = [];
    e2_cur  = [];
    sA      = [];
    sB      = [];
    
    fn = @checkValues;
    
    function checkValues(eps1,eps2,z0)
        if isempty(z0_cur) || norm(z0 - z0_cur) > 0
            z0_cur      = z0;
            e1_cur      = eps1;
            e2_cur      = eps2;
            sA          = svd(A - z0*speye(size(A)));
            sB          = svd(B - z0*speye(size(B)));
            checkEpsilon(sA,eps1);
            checkEpsilon(sB,eps2);
        else
            if e1_cur ~= eps1
                checkEpsilon(sA,eps1);
                e1_cur  = eps1;
            end
            if e2_cur ~= eps2
                checkEpsilon(sB,eps2);
                e2_cur  = eps2;
            end
        end
    end
    
    function checkEpsilon(sv,epsln)
        assert(isfinite(epsln) && min(abs(sv - epsln)) > epsln*eps_tol);
    end
end