function data = makeSection91(save_files)
% This generates the data for Section 9.1 in the paper, i.e., the plots in 
% Figures 9.1 and 9.2 and the row data for Table 9.1.
%   
% This software is only intended as a proof-of-concept and is not yet tuned
% for efficiency.  Optimized routines for general computational use will be
% added to a future release of
%
% ROSTAPACK: RObust STAbility PACKage
% http://www.timmitchell.com/software/ROSTAPACK/
%
%
% Authored by: Tim Mitchell
% Email: mitchell@mpi-magdeburg.mpg.de
% Date: November 7, 2019
% License: AGPL
%
% =========================================================================
% |  makeSection91.m                                                      |
% |  Copyright (C) 2019 Tim Mitchell                                      |
% |                                                                       |
% |  This program is free software: you can redistribute it and/or modify |
% |  it under the terms of the GNU Affero General Public License as       |
% |  published by the Free Software Foundation, either version 3 of       |
% |  the License, or (at your option) any later version.                  |
% |                                                                       |
% |  This program is distributed in the hope that it will be useful,      |
% |  but WITHOUT ANY WARRANTY; without even the implied warranty of       |
% |  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
% |  GNU Affero General Public License for more details.                  |
% |                                                                       |
% |  You should have received a copy of the GNU Affero General Public     |
% |  License along with this program.  If not, see                        |
% |  <http://www.gnu.org/licenses/agpl.html>.                             |
% =========================================================================

    z0          = [];       % don't specify a search point
    z0s         = 10+10i;   % initial point for optimization
    [A,B,I]     = getExample(10);
    shifts      = [10,5,0];
    use_line    = true;
    plots       = true;
    
    save_files  = nargin > 0 && save_files;
    
    data        = cell(length(shifts),1);
  
    for j = 1:length(shifts)
        s   = shifts(j);
        As  = A - s*I;
        Bs  = B + s*I;
        
        d.mn            = 10;
        d.s             = s;
        
        [dD,h1,h2,h3]   = getSepLamDemo(As,Bs,z0,z0s,use_line,false,plots);
        d.getSepLam     = dD;
        
        [dE,h4,h5,h6]   = getSepLamDemo(As,Bs,z0,z0s,use_line,true,plots);
        d.getSepLam_sum = dE;
        
        [dV,h7,h8]      = getSepLamVDemo(As,Bs,plots);
        d.getSepLamV    = dV;

        data{j}         = d;
       
        if save_files
            saveas(h1,['sld_shift' int2str(s) '_ps'],'epsc');
            saveas(h2,['sld_shift' int2str(s) '_lin'],'epsc');
            saveas(h3,['sld_shift' int2str(s) '_log'],'epsc');
           
            saveas(h4,['slv_est_shift' int2str(s) '_ps'],'epsc');
            saveas(h5,['slv_est_shift' int2str(s) '_lin'],'epsc');
            saveas(h6,['slv_est_shift' int2str(s) '_log'],'epsc');
            
            saveas(h7,['slv_shift' int2str(s) '_ps'],'epsc');
            saveas(h8,['slv_shift' int2str(s) '_lin'],'epsc');
        end
    end
   
    if save_files 
        diary('section91_tables.txt');
    end
            
    fprintf('\nTable 9.1:\n');
    printTable91(data);
    fprintf('\n');
    
    fprintf('\nTable 9.2:\n');
    printTable92(data);
    fprintf('\n');
    
    if save_files
        diary OFF
        save section91.mat data
    end
   
end