function [h1,h2] = plotCompsFn(A,B,eps1,eps2,z0,use_line)
% This is used to create the plots in Figure 4.1.
%   
% This software is only intended as a proof-of-concept and is not yet tuned
% for efficiency.  Optimized routines for general computational use will be
% added to a future release of
%
% ROSTAPACK: RObust STAbility PACKage
% http://www.timmitchell.com/software/ROSTAPACK/
%
%
% Authored by: Tim Mitchell
% Email: mitchell@mpi-magdeburg.mpg.de
% Date: November 7, 2019
% License: AGPL
%
% =========================================================================
% |  plotCompsFn.m                                                        |
% |  Copyright (C) 2019 Tim Mitchell                                      |
% |                                                                       |
% |  This program is free software: you can redistribute it and/or modify |
% |  it under the terms of the GNU Affero General Public License as       |
% |  published by the Free Software Foundation, either version 3 of       |
% |  the License, or (at your option) any later version.                  |
% |                                                                       |
% |  This program is distributed in the hope that it will be useful,      |
% |  but WITHOUT ANY WARRANTY; without even the implied warranty of       |
% |  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
% |  GNU Affero General Public License for more details.                  |
% |                                                                       |
% |  You should have received a copy of the GNU Affero General Public     |
% |  License along with this program.  If not, see                        |
% |  <http://www.gnu.org/licenses/agpl.html>.                             |
% =========================================================================

    close all
    
    colors  = lines(3);
    
    imag_tol    = 1e-8;
    eps_tol     = 1e-8;
    
    if use_line
        th_lb   = 0;
        ticksFn = @ticks0topi;
    else
        th_lb   = -pi;
        ticksFn = @tickspitopi;
    end
    opts.imag_tol       = imag_tol;
    opts.eps_tol        = eps_tol;
    opts.use_line       = use_line;
    opts.min_samples    = 17;
    
    cert    = makeInterpCert(A,B,z0,@() error('bad z0'),[th_lb pi],opts);
    compFn  = cert.getComp;
    
    dist    = makeSepLamCertFn(A,B,imag_tol,eps_tol,use_line);
    dist.init(eps1,eps2,z0)
    
    h1 = plotEigs(A,B);
    xlim([-6 6])
    ylim([-6 6])
    r   = sqrt(max(xlim())^2 + max(ylim())^2);
    ths = linspace(0,pi,9);
    ths = ths(1:end-1);
    arrayfun(@(th) plot(complex(z0 + [-r r]*exp(1i*th)),'k--'),ths);
    makePsPlots(A,B,eps1,eps2);
    plot(complex(z0),'kx','LineWidth',2);
    largerTicks();
    tightFigure();
   
   
    h2 = figure();
    hold on 
    xlim([th_lb pi]);
    ths     = linspace(th_lb,pi,1000);
    [a,b,l] = compFn(eps1,eps2,ths); 
    plot(ths,a,'-','LineWidth',2,'Color',[ 0 0 1]);
    plot(ths,b,':','LineWidth',2,'Color',[ 1 0 0]);
    plot(ths,l,'--','LineWidth',2,'Color',colors(3,:));
    xlim([th_lb pi]);
    grid on
    ticksFn();
    largerTicks();
    tightFigure();
    
end