function data = runComparison(n,s)
% This compares our new method with Gu's and Overton's method for computing
% sep_\lambda(A,B)^D.  It is used to generate each row in Table 2.
% 
%   n:      problem size: 10, 20, or 40
%   s:      shift size: 0 or n
%   
% This software is only intended as a proof-of-concept and is not yet tuned
% for efficiency.  Optimized routines for general computational use will be
% added to a future release of
%
% ROSTAPACK: RObust STAbility PACKage
% http://www.timmitchell.com/software/ROSTAPACK/
%
%
% Authored by: Tim Mitchell
% Email: mitchell@mpi-magdeburg.mpg.de
% Date: November 7, 2019
% License: AGPL
%
% =========================================================================
% |  runComparison.m                                                      |
% |  Copyright (C) 2019 Tim Mitchell                                      |
% |                                                                       |
% |  This program is free software: you can redistribute it and/or modify |
% |  it under the terms of the GNU Affero General Public License as       |
% |  published by the Free Software Foundation, either version 3 of       |
% |  the License, or (at your option) any later version.                  |
% |                                                                       |
% |  This program is distributed in the hope that it will be useful,      |
% |  but WITHOUT ANY WARRANTY; without even the implied warranty of       |
% |  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
% |  GNU Affero General Public License for more details.                  |
% |                                                                       |
% |  You should have received a copy of the GNU Affero General Public     |
% |  License along with this program.  If not, see                        |
% |  <http://www.gnu.org/licenses/agpl.html>.                             |
% =========================================================================
  
    use_line    = true;
    use_sum     = false;
    plots       = false;
    z0          = [];   % don't specify a search point
    z0s         = 0;    % use the origin to start optimization
    [A,B,I]     = getExample(n);
    As          = A - s*I;
    Bs          = B + s*I;
    
    data.mn     = n;
    data.s      = s;
    
    fprintf('Testing m=n=%d s=%d...\n',n,s);
        
    fprintf('\nRunning new method... ');
    data.getSepLam = getSepLamDemo(As,Bs,z0,z0s,use_line,use_sum,plots);
    fprintf('took %.1f seconds.\n',data.getSepLam.t);
        
    fprintf('\n\nRunning method of Gu and Overton... ');
    data.seplambda = runGuOverton(As,Bs,plots);
    fprintf('took %.1f seconds.\n',data.seplambda.t);
        
    fprintf('\nA Row of Table 9.3:\n');
    
    printTable93(data);
    
end
