function fn = getSigmaMinAB(A,B,use_sum,svd_type)
% Returns a function handle to compute the value and gradient of f^V(z) or
% f^D(z), which are defined in (1.4).
% 
%   A:          an m by m matrix
%   B:          an n by n matrix
%   use_sum:    logical: true computes f^V(z), f^D(z) otherwise
%   svd_type:   0: sparse mode, not yet implemented
%               1: computes minumum singular value directly
%               2: mathematically equivalent to 1 but does it by 
%                  computing maximum singular value of inverse of 
%                  zE - A (because svd can sometimes be very inaccurate 
%                  when the minimum singular value is needed).
%
% This software is only intended as a proof-of-concept and is tuned for 
% demonstration purposes, not efficiency.  Optimized routines for 
% general computational use will be added to a future release of 
%
% ROSTAPACK: RObust STAbility PACKage
% http://www.timmitchell.com/software/ROSTAPACK/
%   
%
% Authored by: Tim Mitchell
% Email: mitchell@mpi-magdeburg.mpg.de
% Date: November 7, 2019
% License: AGPL
%
% =========================================================================
% |  getSigmaMinAB.m                                                      |
% |  Copyright (C) 2019 Tim Mitchell                                      |
% |                                                                       |
% |  This program is free software: you can redistribute it and/or modify |
% |  it under the terms of the GNU Affero General Public License as       |
% |  published by the Free Software Foundation, either version 3 of       |
% |  the License, or (at your option) any later version.                  |
% |                                                                       |
% |  This program is distributed in the hope that it will be useful,      |
% |  but WITHOUT ANY WARRANTY; without even the implied warranty of       |
% |  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
% |  GNU Affero General Public License for more details.                  |
% |                                                                       |
% |  You should have received a copy of the GNU Affero General Public     |
% |  License along with this program.  If not, see                        |
% |  <http://www.gnu.org/licenses/agpl.html>.                             |
% =========================================================================
 
    [~,fnA] = makeSigmaMinFn(A,[],false,svd_type);
    [~,fnB] = makeSigmaMinFn(B,[],false,svd_type);
    
    if use_sum
        fn  = @sumAB;
    else
        fn  = @maxAB;
    end
    
    function [f,g,eps1,eps2] = maxAB(x,y)
        [fa,ga] = fnA(x,y);
        [fb,gb] = fnB(x,y);
        if fa > fb
            f   = fa;
            g   = ga;
        else
            f   = fb;
            g   = gb;
        end
        eps1    = f;
        eps2    = f;
    end

    function [f,g,eps1,eps2] = sumAB(x,y)
        [eps1,g1]   = fnA(x,y);
        [eps2,g2]   = fnB(x,y);
        f           = eps1 + eps2; 
        g           = g1 + g2;
    end

end